@@ -1,9 +1,8 @@
 #!/usr/bin/env perl
-
 use strict;
 use warnings;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 =encoding utf-8
 
@@ -13,8 +12,8 @@ fitdump.pl - script to print the contents of Garmin FIT files to standard output
 
 =head1 SYNOPSIS
 
-  fitdump -show_version=1
-  fitdump [ -semicircles_to_deg=(0|1) -mps_to_kph=(0|1) -use_gmtime=(0|1) -maybe_chained=(0|1) ] [ $FIT_file ... ]
+  fitdump.pl -show_version=1
+  fitdump.pl [ -semicircles_to_deg=(0|1) -mps_to_kph=(0|1) -use_gmtime=(0|1) -maybe_chained=(0|1) ] [ $FIT_file ... ]
 
 =head1 DESCRIPTION
 
@@ -186,7 +185,7 @@ Please visit the project page at: L<https://github.com/patjoly/geo-fit>.
 
 =head1 VERSION
 
-1.02
+1.03
 
 =head1 LICENSE AND COPYRIGHT
 
